@@ -28,7 +28,7 @@ from macrometa_source_snowflake.connection import SnowflakeConnection
 
 LOGGER = singer.get_logger('macrometa_source_snowflake')
 
-# Max number of rows that a SHOW SCHEMAS|TABLES|COLUMNS can return.
+# Max number of rows that a SHOW SCHEMAS|TABLE|COLUMNS can return.
 # If more than this number of rows returned then macrometa-source-snowflake will raise TooManyRecordsException
 SHOW_COMMAND_MAX_ROWS = 9999
 
@@ -51,7 +51,7 @@ REQUIRED_CONFIG_KEYS = [
     'dbname',
     'user',
     'warehouse',
-    'tables'
+    'table'
 ]
 
 # Snowflake data types
@@ -125,7 +125,7 @@ def create_column_metadata(cols):
 
 
 def get_table_columns(snowflake_conn, tables):
-    """Get column definitions of a list of tables
+    """Get column definition of a table
 
        It's using SHOW commands instead of INFORMATION_SCHEMA views because information_schemas views are slow
        and can cause unexpected exception of:
@@ -177,8 +177,8 @@ def get_table_columns(snowflake_conn, tables):
 
 def discover_catalog(snowflake_conn, config):
     """Returns a Catalog describing the structure of the database."""
-    tables = config.get('tables').split(',')
-    sql_columns = get_table_columns(snowflake_conn, tables)
+    table = [config.get('table')]
+    sql_columns = get_table_columns(snowflake_conn, table)
 
     table_info = {}
     columns = []
@@ -347,7 +347,7 @@ def get_streams(snowflake_conn, catalog, config, state):
     sync).
 
     Using the Catalog provided from the input file, this function will return a
-    Catalog representing exactly which tables and columns that will be emitted
+    Catalog representing exactly which table and columns that will be emitted
     by SELECT-based syncs. This is achieved by comparing the input Catalog to a
     freshly discovered Catalog to determine the resulting Catalog.
 
@@ -668,11 +668,9 @@ class SnowflakeSourceConnector(C8Connector):
             ConfigProperty('warehouse', 'Warehouse', ConfigAttributeType.STRING, True, False,
                            description='Snowflake virtual warehouse name.',
                            placeholder_value='my_warehouse'),
-            ConfigProperty('tables', 'Tables', ConfigAttributeType.STRING, True, False,
-                           description='A comma separated list of the table names that you want to sync.'
-                                       ' The table names should be fully qualified including the db and schema name.'
-                                       ' For example, syncing table1 and table2 would look like'
-                                       ' `db.schema.table1,db.schema.table2`.',
+            ConfigProperty('table', 'Table', ConfigAttributeType.STRING, True, False,
+                           description='Name of the table that you want to sync.'
+                                       ' The table name should be fully qualified including the db and schema name.',
                            placeholder_value='my_db.my_schema.my_table'),
             ConfigProperty('replication_method', 'Replication Method',
                            ConfigAttributeType.STRING, True, False,
@@ -714,7 +712,7 @@ class SnowflakeSourceConnector(C8Connector):
                 'user': integration['user'],
                 'password': integration['password'],
                 'warehouse': integration['warehouse'],
-                'tables': integration['tables'],
+                'table': integration['table'],
                 # Optional config keys
                 'primary_key': integration.get('primary_key'),
                 'role': integration.get('role'),
